package ch.bbw.pr.tresorbackend.service;

import ch.bbw.pr.tresorbackend.model.User;
import lombok.Value;
import org.bouncycastle.util.encoders.Hex;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.security.SecureRandom;
import java.util.Objects;

/**
 * PasswordEncryptionService
 *
 * @author Peter Rutschmann
 */
@Service
public class PasswordEncryptionService {

    @Autowired
    private PepperService pepperService;

    private final BCryptPasswordEncoder encoder;

    public PasswordEncryptionService() {
        this.encoder = new BCryptPasswordEncoder();
    }

    public String hashPassword(String password) {
        String pepper = pepperService.getPepper();

        if (pepper == null || pepper.isEmpty()) {
            throw new IllegalStateException("Pepper is missing or empty");
        }

        // Combine pepper and password, let BCrypt handle salting internally
        String connectedPassword = pepper + password;
        return encoder.encode(connectedPassword);
    }

    public boolean verifyPassword(User user, String password) {
        String pepper = pepperService.getPepper();

        if (pepper == null || pepper.isEmpty()) {
            throw new IllegalStateException("Pepper is missing or empty");
        }

        // Reconstruct the original password with pepper
        String connectedPassword = pepper + password;

        // Directly compare the stored hash with the user input
        return encoder.matches(connectedPassword, user.getPassword());
    }
}
